@@ -1,16 +1,17 @@
 __all__ = [
-    "__title__", "__summary__", "__uri__", "__version__", "__author__",  "__email__",
+    "__title__",
+    "__summary__",
+    "__uri__",
+    "__author__",
+    "__email__",
 ]
 
 __title__ = "gbd_mapping"
 __summary__ = "A programmatically accessible mapping of gbd entities."
 __uri__ = "https://github.com/ihmeuw/gbd_mapping"
 
-__version__ = "3.0.5"
-
 __author__ = "The vivarium developers"
 __email__ = "vivarium.dev@gmail.com"
 
 __license__ = "BSD-3-Clause"
-__copyright__ = f"Copyright 2022 {__author__}"
-
+__copyright__ = f"Copyright 2023 {__author__}"
